// Copyright (c) 2003 Charles Samuels <charles@kde.org>
// See the file COPYING for redistribution terms.

#include "oblique.h"
#include "base.h"
#include "tree.h"
#include "file.h"
#include "selector.h"
#include "cmodule.h"

#include <kconfig.h>
#include <kstddirs.h>

extern "C" Plugin *create_plugin()
{
	return new Oblique();
}



Oblique::Oblique()
	: Playlist(0, 0), mSchemaCollection("oblique/schemas")
{
	mView = 0;
	KConfigGroup g(KGlobal::config(), "oblique");

	mFileOfQuery = g.readEntry("schema", "standard");
	loadQuery(mFileOfQuery);

	mBase = new Base(::locate("data", "noatun/")+"/oblique-list");
	mView = new Tree(this, &mQuery);
	connect(mView, SIGNAL(selected(TreeItem*)), SLOT(selected(TreeItem*)));

	mSelector = new SequentialSelector(mView);

	new Configure(this);

	mView->connect(mBase, SIGNAL(added(File)), SLOT(insert(File)));
	mView->connect(mBase, SIGNAL(removed(File)), SLOT(remove(File)));

	// psst, window's gone, pass it on!
	connect(mView, SIGNAL(listHidden()), SIGNAL(listHidden()));
	connect(mView, SIGNAL(listShown()), SIGNAL(listShown()));

	loadQuery(mFileOfQuery);

}

void Oblique::loadQuery(const QString &name)
{
	mFileOfQuery = name;
	mQuery.load(schemaCollection().file(name, false));

	if (mView)
	{
		mView->reset();
		FileId high = mBase->high();
		for (FileId pot=1; pot <= high; pot++)
		{
			File f = mBase->find(pot);
			if (f)
				mView->insert(f);
		}
	}
}

Oblique::~Oblique()
{
	delete mView;
	delete mBase;
}

void Oblique::reset()
{
	setCurrent(getFirst());
}

void Oblique::clear()
{
	mBase->clear();
}

void Oblique::addFile(const KURL &url, bool play)
{
	(void)play; // TODO
	mBase->add(url.path());
}


PlaylistItem Oblique::next()
{
	return mSelector->next();
}

PlaylistItem Oblique::previous()
{
	return mSelector->previous();
}


PlaylistItem Oblique::current()
{
	return mSelector->current();
}

void Oblique::setCurrent(const PlaylistItem &item)
{
	mSelector->setCurrent(*static_cast<Item*>(const_cast<PlaylistItemData*>(item.data())));
}


PlaylistItem Oblique::getFirst() const
{
	SequentialSelector s(mView);
	return s.current();
}


PlaylistItem Oblique::getAfter(const PlaylistItem &item) const
{
	SequentialSelector s(mView);
	s.setCurrent(*const_cast<Item*>(static_cast<const Item*>(item.data())));
	return s.next();
}

bool Oblique::listVisible() const
{
	return mView->isVisible();
}

void Oblique::showList()
{
	mView->show();
}

void Oblique::hideList()
{
	mView->hide();
}


void Oblique::selected(TreeItem *cur)
{
	Item item(cur->file());
	mSelector->setCurrent(item);
}


#include "oblique.moc"

